@@ -1,6 +1,7 @@
 import asyncio
 import os
 import random
+import sys
 from datetime import datetime as dt
 from pathlib import Path
 
@@ -8,11 +9,13 @@ import loguru
 from apscheduler.executors.asyncio import AsyncIOExecutor
 from apscheduler.triggers.interval import IntervalTrigger
 from pydantic import BaseModel
-from sanic import json, Sanic
+from sanic import json, Sanic, Request
+from sanic_ext.config import add_fallback_config
 from sanic_ext.extensions.openapi.blueprint import blueprint_factory
 from sanic_ext.extensions.openapi.builders import SpecificationBuilder
+from sanic_ext.extensions.openapi.extension import OpenAPIExtension
 from tortoise import fields
-from json import dump
+from json import dump, load
 
 from web_foundation import settings
 from web_foundation.config import DbConfig, AppConf
@@ -21,6 +24,7 @@ from web_foundation.extentions.metrics.exporter import JsonExporter
 from web_foundation.extentions.metrics.metric import CounterMetric
 from web_foundation.extentions.metrics.events import NewMetricEvent
 from web_foundation.extentions.metrics.service import MetricsService
+from web_foundation.extentions.openapi_gen import generate_openapi
 from web_foundation.extentions.realtime.sse import SseRtMessage, SseRtConnection
 from web_foundation.extentions.request_handler import ChainRequestHandler, InputContext
 from web_foundation.extentions.router import DictRouter
@@ -83,15 +87,6 @@ if __name__ == '__main__':
     dispatcher = IDispatcher(scheduler=scheduler)
     app = App(dependency_container=container, dispatcher=dispatcher)
 
-    async def generate_openapi(s_app: Sanic):
-
-        oas_json = SpecificationBuilder().build(s_app).serialize()
-        with open("openapi.json", 'w') as f:
-            dump(oas_json, f)
-
-    app.sanic.after_server_start(generate_openapi)
-
-
     # app.sanic.config.HEALTH = True
     # app.sanic.config.HEALTH_ENDPOINT = True
     async def check_add(s_app, *args, **kwargs):
@@ -211,9 +206,13 @@ if __name__ == '__main__':
             }
         ]
     }
-    router = DictRouter(routes_dict, ChainRequestHandler)
+    router = DictRouter(routes_dict, ChainRequestHandler, open_api=True)
     app.add_custom_router(router)
 
+    if "generate_openapi" in sys.argv:
+        generate_openapi(app, json_filepath=app.config.openapi_filepath)
+        sys.exit()
+
     # app.add_isolate("AAAA", NewIsolate, app=app)
     app.subscribe_worker(TestEvent, resolve_callback=resolve_sse)
     app.run()
