@@ -61,7 +61,7 @@ class DictRouter(ExtRouter, Generic[GenericRequestHandler]):
                  routes_config: Dict,
                  ext_handler: GenericRequestHandler,
                  versioning: bool = True,
-                 open_api: bool = True):
+                 open_api: bool = False):
         super().__init__(ext_handler)
         self._router_conf = routes_config
         self.versioning = versioning
@@ -71,13 +71,21 @@ class DictRouter(ExtRouter, Generic[GenericRequestHandler]):
         for app_route in self._router_conf.get("apps"):
             version_prefix = app_route.get("version_prefix")
             version_prefix = version_prefix if version_prefix else "/api/v"
+            if not isinstance(app_route, dict):
+                continue
             for endpoint, versions in app_route.get("endpoints").items():
+                if not isinstance(versions, dict):
+                    continue
                 for version, params in versions.items():
+                    if not isinstance(params, dict):
+                        continue
                     methods_confs = []
                     endpoint_handler = params.pop("handler", None)
                     endpoint_protector = params.pop("protector", None)
                     endpoint_response_fabric = params.pop("response_fabric", None)
                     for method_name, method_params in params.items():
+                        if not isinstance(method_params, dict):
+                            continue
                         target_func = method_params.get('handler')
                         target_func = target_func if target_func else endpoint_handler
                         protector = method_params.get("protector")
