@@ -22,6 +22,7 @@ from apscheduler.triggers.base import BaseTrigger
 from apscheduler.triggers.interval import IntervalTrigger
 from datetime import timezone
 from web_foundation.kernel.messaging.channel import IMessage
+from web_foundation.utils.helpers import is_in_base_classes
 
 BackgroundTask = TypeVar("BackgroundTask", Callable[..., Coroutine[Any, Any, Any]], partial)
 
@@ -76,6 +77,7 @@ class Task:
     create_time: datetime.datetime | None = field(default_factory=datetime.datetime.now)
     error: BaseException | None = field(default=None)
     return_event: bool = False
+    return_task: bool = False
 
 
 class TaskIMessageReturn(IMessage):
@@ -176,6 +178,9 @@ class TaskScheduler:
                 if task.on_complete_callback:
                     asyncio.create_task(task.on_complete_callback(event, task))
                 if task.return_event:
+                    if is_in_base_classes(event.retval, IMessage):
+                        asyncio.create_task(self.produce_method(event.retval))
+                if task.return_task:
                     ret_event = TaskIMessageReturn(task)
                     asyncio.create_task(self.produce_method(ret_event))
 
