@@ -15,6 +15,7 @@ from web_foundation.config import AppConf
 from web_foundation.extentions.error_handler import ExtendedErrorHandler
 from web_foundation.extentions.metrics.events import NewMetricEvent
 from web_foundation.extentions.metrics.metric import HistogramMetric, CounterMetric, SummaryMetric, Metric
+from web_foundation.extentions.openapi_gen import add_openapi
 from web_foundation.extentions.realtime.broadcaster import RtBroadcaster
 from web_foundation.extentions.realtime.connection import RtEventCallback
 from web_foundation.extentions.router import ExtRouter
@@ -105,9 +106,13 @@ class App(Generic[GenericDependencyContainer]):
             await listener(stage, self.container)
 
     def _set_sanic_confs(self):
-        self.sanic.config.SWAGGER_UI_CONFIGURATION = {
-            "docExpansion": 'none'
-        }
+        if hasattr(self.config, "openapi_filepath") and self.config.openapi_filepath:
+            self.sanic.config.SWAGGER_UI_CONFIGURATION = {
+                "docExpansion": 'none'
+            }
+            add_openapi(self)
+        else:
+            self.sanic.config.OAS = False
 
     def _configure_sanic_main(self):
         async def on_start(s_app: Sanic):
